Post

Astro 7.4 ships experimental parallel prerendering. I tried it on the Astro docs (6,358 pages): build time went from 67s to 37s, 45% faster. 🚀

5 reposts51 likes

I remember this being quite hard to work out to share state between threads. Glad yall had figured it out!

The refactors we had to do to have prerendering running in workerd for the Cloudflare adapter helped a lot!